@@ -3,7 +3,7 @@
 # Name     : ModProxyPerlHtml.pm
 # Language : perl 5
 # Authors  : Gilles Darold, gilles at darold dot net
-# Copyright: Copyright (c) 2005-2011: Gilles Darold - All rights reserved -
+# Copyright: Copyright (c) 2005-2012: Gilles Darold - All rights reserved -
 # Description : This mod_perl2 module is a replacement for mod_proxy_html.c
 #		with far better URL HTML rewriting.
 # Usage    : See documentation in this file with perldoc.
@@ -28,7 +28,9 @@ use constant BUFF_LEN => 8000;
 use Apache2::ServerRec;
 use Apache2::URI;
 
-$Apache2::ModProxyPerlHtml::VERSION = '3.3';
+
+$Apache2::ModProxyPerlHtml::VERSION = '3.5';
+
 
 %Apache2::ModProxyPerlHtml::linkElements = (
 	'a'       => ['href'],
@@ -128,7 +130,7 @@ sub handler
 		my $refresh = $f->r->headers_out->{'Refresh'};
 		if ($refresh) {
 			foreach my $p (@{$ctx->{pattern}}) {
-				my ($match, $substitute) = split(/[\s\t]+/, $p);
+				my ($match, $substitute) = split(/[\s\t]+/, $p, 2);
 				if ($refresh =~ s#([^\/:])$match#$1$substitute#) {
 					if ($debug) {
 						Apache2::ServerRec::warn("[ModProxyPerlHtml] Refresh header match '$match', substituted by: /$substitute/\n");
@@ -137,6 +139,18 @@ sub handler
 			}
 			$f->r->headers_out->set('Refresh' => $refresh);
 		}
+		my $referer = $f->r->headers_out->{'Referer'};
+		if ($referer) {
+			foreach my $p (@{$ctx->{pattern}}) {
+				my ($match, $substitute) = split(/[\s\t]+/, $p, 2);
+				if ($referer =~ s#([^\/:])$match#$1$substitute#) {
+					if ($debug) {
+						Apache2::ServerRec::warn("[ModProxyPerlHtml] Referer header match '$match', substituted by: /$substitute/\n");
+					}
+				}
+			}
+			$f->r->headers_out->set('Referer' => $referer);
+		}
 		
 		if ( ($content_type =~ /$ctx->{contenttype}/is) && ($content_type !~ /$ctx->{badcontenttype}/is) ) {
 			if ($debug) {
@@ -144,13 +158,13 @@ sub handler
 			}
 			# Replace links if pattern match
 			foreach my $p (@{$ctx->{pattern}}) {
-				my ($match, $substitute) = split(/[\s\t]+/, $p);
+				my ($match, $substitute) = split(/[\s\t]+/, $p, 2);
 				&link_replacement(\$ctx->{data}, $match, $substitute, $parsed_uri);
 
 			}
 			# Rewrite code if rewrite pattern match
 			foreach my $p (@{$ctx->{rewrite}}) {
-				my ($match, $substitute) = split(/[\s\t]+/, $p);
+				my ($match, $substitute) = split(/[\s\t]+/, $p, 2);
 				&rewrite_content(\$ctx->{data}, $match, $substitute, $parsed_uri);
 			}
 		}
@@ -275,8 +289,8 @@ Apache2::ModProxyPerlHtml is very simple and has far better parsing/replacement
 of URL than the original C code. It also support meta tag, CSS, and javascript
 URL rewriting and can be use with compressed HTTP. You can now replace any code
 by other, like changing images name or anything else. mod_proxy_html can't do
-all of that. Since release 3.0 ModProxyPerlHtml is also able to rewrite HTTP
-headers with refresh url redirection. 
+all of that. Since release 3.x ModProxyPerlHtml is also able to rewrite HTTP
+headers with Refresh url redirection and Referer. 
 
 The replacement capability concern only the following HTTP content type:
 
@@ -350,6 +364,9 @@ follow:
     <Location /webcal/>
         ...
         PerlAddVar ProxyHTMLRewrite "/logo/image1.png /images/logo1.png"
+	# Or more complicated to handle space in the code as space is the
+	# pattern / substitution separator character internally in ModProxyPerlHtml
+	PerlAddVar ProxyHTMLRewrite "ajaxurl[\s\t]*=[\s\t]*'/blog' ajaxurl = '/www2.mydom.org/blog'"
         ...
     </Location>
 
@@ -375,7 +392,7 @@ ProxyHTMLContentType configuration directive to redefined the HTTP Content Type
 that should be parsed by ModProxyPerlHTML. The default value is the following
 Perl regular expresssion:
 
-	ProxyHTMLContentType    (text\/javascript|text\/html|text\/css|text\/xml|application\/.*javascript|application\/.*xml)
+	PerlAddVar ProxyHTMLContentType    (text\/javascript|text\/html|text\/css|text\/xml|application\/.*javascript|application\/.*xml)
 
 If you know exactly what you are doing by editing this regexp fill free to add
 the missing Content-Type that must be parsed by ModProxyPerlHTML. Otherwise drop
@@ -468,7 +485,7 @@ requests.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2011 - Gilles Darold
+Copyright (c) 2005-2012 - Gilles Darold
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
